aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/SkSpecialImage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/SkSpecialImage.h')
-rw-r--r--src/core/SkSpecialImage.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/core/SkSpecialImage.h b/src/core/SkSpecialImage.h
index 8ccff0e056..bf168f02af 100644
--- a/src/core/SkSpecialImage.h
+++ b/src/core/SkSpecialImage.h
@@ -136,10 +136,15 @@ public:
#if SK_SUPPORT_GPU
/**
* Regardless of the underlying backing store, return the contents as a GrTextureProxy.
* The active portion of the texture can be retrieved via 'subset'.
*/
- sk_sp<GrTextureProxy> asTextureProxyRef(GrContext*) const;
+ sk_sp<GrTexture> asTextureRef(GrContext*) const;
+
+ /**
+ * The same as above but return the contents as a GrTextureProxy.
+ */
+ sk_sp<GrTextureProxy> asTextureProxy(GrContext*) const;
#endif
// TODO: hide this whe the imagefilter all have a consistent draw path (see skbug.com/5063)
@@ -136,10 +136,15 @@ public:
#if SK_SUPPORT_GPU
/**
- * Regardless of the underlying backing store, return the contents as a GrTextureProxy.
+ * Regardless of the underlying backing store, return the contents as a GrTexture.
* The active portion of the texture can be retrieved via 'subset'.
*/